==> dimples-1.3.3-py3-none-any.whl: dimples/database/redis/__init__.py <==
# -*- coding: utf-8 -*-
# ==============================================================================
# MIT License
#
# Copyright (c) 2021 Albert Moky
#
# Permission is hereby granted, free of charge, to any person obtaining a copy
# of this software and associated documentation files (the "Software"), to deal
# in the Software without restriction, including without limitation the rights
# to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
# copies of the Software, and to permit persons to whom the Software is
# furnished to do so, subject to the following conditions:
#
# The above copyright notice and this permission notice shall be included in all
# copies or substantial portions of the Software.
#
# THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
# IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
# FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
# AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
# LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
# OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
# SOFTWARE.
# ==============================================================================

"""
    Database module
    ~~~~~~~~~~~~~~~
    Redis Client
"""

from .base import RedisConnector
from .base import Cache as RedisCache

from .meta import MetaCache
from .document import DocumentCache
from .user import UserCache
from .login import LoginCache
from .group import GroupCache
from .grp_history import GroupHistoryCache
from .grp_keys import GroupKeysCache
from .message import MessageCache
from .station import StationCache


__all__ = [

    'RedisConnector',
    'RedisCache',

    'MetaCache',
    'DocumentCache',
    'UserCache', 'LoginCache',
    'GroupCache', 'GroupHistoryCache',
    'GroupKeysCache',
    'MessageCache',
    'StationCache',

]

==> dimples-1.4.0-py3-none-any.whl: dimples/database/redis/__init__.py <==
# -*- coding: utf-8 -*-
# ==============================================================================
# MIT License
#
# Copyright (c) 2021 Albert Moky
#
# Permission is hereby granted, free of charge, to any person obtaining a copy
# of this software and associated documentation files (the "Software"), to deal
# in the Software without restriction, including without limitation the rights
# to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
# copies of the Software, and to permit persons to whom the Software is
# furnished to do so, subject to the following conditions:
#
# The above copyright notice and this permission notice shall be included in all
# copies or substantial portions of the Software.
#
# THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
# IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
# FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
# AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
# LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
# OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
# SOFTWARE.
# ==============================================================================

"""
    Database module
    ~~~~~~~~~~~~~~~
    Redis Client
"""

from .base import RedisConnector
from .base import RedisCache

from .meta import MetaCache
from .document import DocumentCache
from .user import UserCache
from .login import LoginCache
from .group import GroupCache
from .grp_history import GroupHistoryCache
from .grp_keys import GroupKeysCache
from .message import MessageCache
from .station import StationCache


__all__ = [

    'RedisConnector',
    'RedisCache',

    'MetaCache',
    'DocumentCache',
    'UserCache', 'LoginCache',
    'GroupCache', 'GroupHistoryCache',
    'GroupKeysCache',
    'MessageCache',
    'StationCache',

]
